PokemonPets Official Forum

Hello There, Guest! Login Register

Official Forums
Forum | Threads | Posts | Last Post
|  | Test Server Information, Discussions And News About Test Server Sub Forums: Test server version change logs, Hotfixes | 1 | 6 | hey is testserver there 07-21-2015 01:04 AM by pratham
|  | Announcements All announcements about the game and forum. Sub Forums: Events | 11 | 111 | More than 30 days inactiv... 10-26-2015 11:44 AM by Cpt. Obvious
|  | Version Records Game's Update Records List. Shows all the different versions of the game here. | 30 | 635 | Version 2.2.4 01-29-2016 07:40 AM by Jules
|  | FAQ Frequently Asked Questions | 23 | 318 | Daily Rewards System Today 05:27 PM by Daeva13
|  | Rules Forum rules, Chat rules, General Rules. | 3 | 3 | Signature Rules 07-03-2014 04:42 AM by Dark.Zero
|  | Forum Suggestions | 2 | 16 | Lets know more 08-31-2015 05:07 PM by CeFurkan
|  | Idea Development | 49 | 356 | Weekly Challenge System 01-27-2016 02:44 AM by staff
|  | World News News about the world can be posted here. | 13 | 74 | the world in darkness for... 11-21-2015 09:53 PM by ash ketchum 11
|  | Screenshots Post your game screenshots here. | 22 | 122 | Can't Catch that Hoopa 01-12-2016 04:38 AM by Riako

Pokemon Pets Information about the game and anything related to it.
Forum | Threads | Posts | Last Post
|  | General Discussions Game related discussions are here. Sub Forums: Pokemon Pets Ads, Polls/Voting | 98 | 1,449 | Major Implementation - 20... Yesterday 07:05 AM by Blau
|  | In-Game Suggestions Have a suggestion that could improve gaming? Show it here. Sub Forums: Implemented Suggestions (Locked) | 166 | 1,352 | pokemon championship 01-28-2016 07:33 AM by cyni
|  | Pokémon Requests From Artists Post your requests for new Pokémon or Pokémon that need to be redrawn here. | 10 | 63 | shiny rayquaza 12-29-2015 02:01 AM by naxion199
|  | Questions About the Game If you have a question about how to play, ask us here. | 23 | 282 | evolving 01-28-2016 02:59 AM by CeFurkan
|  | Introductions and Farewells New to the game or leaving the game for a while? Tell us here. Sub Forums: Holidays, Birthdays, Personal Events | 19 | 173 | Quitting 01-14-2016 01:19 PM by servine
|  | Report A User Reports about any rule violators can be posted here. Sub Forums: Handled Reports (Locked) | 27 | 155 | Electrivire 12-29-2015 01:53 AM by Cpt. Obvious

In-Game Error Reports If you find any errors inside the game, show them here so we can fix them.
Forum | Threads | Posts | Last Post
|  | Grammar Issues If you find any grammar errors, post here. | 4 | 13 | wrong spelling 04-15-2015 11:56 AM by mailmeharry2008
|  | Glitches Something weird happening in the game? Provide a screenshot. | 102 | 544 | Poke Ball list in battle 01-28-2016 01:55 PM by Dyx
|  | Lag Any lagging issues? | 3 | 27 | Lagging since new update 07-18-2015 10:32 AM by ch17175
|  | Player vs. Player - PvP Have a problem with the PVP system? Submit them here. | 1 | 2 | PVP 03-25-2015 11:04 AM by CeFurkan
|  | Mechanical Errors If there is a problem with moves, stats, or anything else, this is the place for it. Sub Forums: Move list, Stat issue, Items, Abilities, Maps, Natures | 43 | 177 | Luna gem used on Eevee 01-27-2016 08:51 AM by CeFurkan
|  | Bugs & Errors Reports - Old Category - Locked For New Threads Bugs & Errors Reports - Old Category - Locked For New Threads | 0 | 0 | Never

Community Zone This is where tournaments, guilds, tips, etc. are hosted.
Forum | Threads | Posts | Last Post
|  | Clans/Guilds/Teamwork You are free to host teams for the game. | 12 | 217 | Sgt's Army 12-24-2015 06:11 AM by M.Blaze99
|  | Tournaments/Competitions Money, prizes, pvp battles! | 17 | 375 | The Diamond League 11-20-2015 07:18 PM by Atharvaa898
|  | Trainer Tips Have any tips to share? Well hurry up and share them. Sub Forums: Guides, Competitive Strategies | 66 | 564 | Shop part 2 how can sell ... 01-30-2016 01:13 AM by GurvinderS1666
|  | PVP Matches Everyone can host matches against each other or see who is better. | 2 | 15 | Lets Gather 11-15-2015 04:19 AM by Sgt_Redhawk
|  | General Chat Tired of the in-game chat? You can use this space to chat. | 31 | 180 | Announcement 01-24-2016 12:33 AM by Jules
|  | Pokémon Ratings If you want to have ratings on your Pokémon, post here. | 3 | 14 | THIS IS GOOD? 10-30-2015 09:30 AM by misterdoorknob

The Market Advertise what you have in the market.
Forum | Threads | Posts | Last Post
|  | Pokémon Bazaar Advertise your sales or ask to buy Pokémon. | 12 | 47 | ch17175's Bazaar 01-30-2016 10:57 PM by ch17175
|  | Trading Looking for a specific Pokémon? Ask here. | 12 | 45 | starter 12-27-2015 01:02 AM by M.Blaze99
|  | Item Bazaar Advertise your sales or ask to buy items. | 1 | 1 | Iteam Bazzar 10-16-2015 09:40 AM by MikeDevil
|  | Auction House Place your bids on Pokémon. | 7 | 70 | HUNTS 12-07-2015 06:51 AM by EeveeGirl360
|  | Services User Services | 23 | 178 | Limited EV Training Servi... 01-27-2016 01:43 AM by jecklin

Game Mechanics Information about the game mechanics are here.
Forum | Threads | Posts | Last Post
|  | Move List | 3 | 16 | bulbasaur 09-24-2015 11:35 AM by subject zero
|  | Maps | 1 | 3 | MAPS 07-15-2015 01:43 AM by CeFurkan
|  | EV Points or IV Points Effort Values , Individual Values systems | 1 | 3 | ev points 01-12-2016 04:48 AM by Riako
|  | Natures | 2 | 6 | LIST OF THE NATURES 07-15-2015 01:49 AM by CeFurkan
|  | Items | 1 | 2 | UNHAPPINESS POTION 07-27-2015 12:16 AM by Jules
|  | Pokémon | 4 | 13 | Re suggested Suggestion f... 10-11-2015 09:17 PM by Glaceon
|  | Abilities | 2 | 26 | crazy abilies and madness... 08-08-2015 01:39 AM by Magic..

Off-Topic Discussions
Forum | Threads | Posts | Last Post
|  | Pokemon Discussions Feel free to talk about Pokemon here. Sub Forums: Official Pokemon Games, Friend Codes, Discussions, Movies/Episodes | 18 | 123 | facts you may or may not ... 12-09-2015 03:41 PM by staff
|  | Nintendo Discussions Feel free to talk about Nintendo's features or products. Sub Forums: WIFI, Systems/Games, Discussions, Arguments | 1 | 3 | 3ds friends 06-29-2015 05:46 AM by Karnine
|  | Off-Topic General Chat Chat about anything that is non-related game material here. Sub Forums: Music, Sports | 8 | 46 | pokemon masters 01-05-2016 11:41 PM by Glaceon
|  | Youtube If you want to share a youtube video, this is the place. | 9 | 55 | My Favorite Song Right No... 01-15-2016 02:37 AM by DarkmagePrince
|  | Television Shows Sub Forums: Comedies and Sitcoms, Reality TV, Competitions and Games shows, Anime, Culinary Shows, Documentaries, HBO/Showtime, Crime Shows | 1 | 7 | The Dere Thread (For Anim... 01-25-2016 06:40 PM by 2008harry
|  | Books Sub Forums: Fantasy, Horror, Thrillers, Comedy, Biographies, Histories, Short Stories, Children's Stories, User penned Stories, Poems and Prose Work, Sci-Fi | 4 | 10 | Jack's Journey 10-23-2015 06:18 AM by MKerogazov
|  | Movies Sub Forums: Horror, Science Fiction, Comedies, Romantic Comedies, Thrillers, War Films, Crime Movies, Anime Movies, Romance Movies | 2 | 4 | Shiny Vs Shiny 10-16-2015 06:19 PM by hendy sakti

Forum Games Games that aren't related to Pokemon Pets can be hosted here.
Forum | Threads | Posts | Last Post
|  | Random Games Random games to ease your boredom. | 4 | 66 | Pokemon Rap Battle 12-31-2015 09:42 PM by Glaceon
|  | Roleplaying A fan of roleplaying? Enjoy it here. | 3 | 33 | Malachi's Life Story 01-15-2016 11:08 AM by ch17175
|  | Pokemon Pets Games Anything related to the game can be played here. | 0 | 0 | Never
|  | Video Games If you want to talk about video games or reenact them here. | 2 | 11 | pokemon fr/lg reveiw (no ... 12-02-2015 04:09 AM by Pokemon Master K

Media
Forum | Threads | Posts | Last Post
|  | Graphics Showcase Anything related to graphic arts. Sub Forums: Graphics Tutorials | 18 | 306 | Shiny-Pokemons by Aladdin 11-16-2015 03:36 AM by Aladdin
|  | Fanfiction Writing Art. Sub Forums: Alternate Fanfiction, Feedback | 20 | 349 | Max Journey Yesterday 01:32 PM by Glaceon
|  | Drawings Present your drawings here. Sub Forums: Pokémon Drawings, Random Drawings | 6 | 132 | The Megas Yesterday 10:44 AM by Glaceon
|  | Creative Arts Section Members can open up a shop and make avatars, signatures and banners asked for by other members | 2 | 63 | [Aladdin's Art Collection... 01-13-2016 12:20 PM by Aladdin
|  | Youtube If you created youtube videos here, share them with us. Sub Forums: Subscriptions | 5 | 31 | Helping Youtubers 11-30-2015 09:41 AM by Glaceon

Board Statistics
Who's Online [Complete List]
1 user active in the past 60 minutes (1 member, 0 of whom are invisible, and 0 guests). Daeva13
Who has been online today [Complete List]
991 users active in the past 24 hours (19 members, 1 of whom is invisible, and 972 guests). ag175008, Aladdin, Atharvaa898, Blau, ch17175, cyni, Daeva13, Delphox, Glaceon, GurvinderS1666, haseeo55, Jules, Kevin Coffe, Mapledodo, qistina, russ3344, servine, Sgt_Redhawk
Board Statistics
Our members have made a total of 8,891 posts in 953 threads. We currently have 9,379 members registered. Please welcome our newest member, DanielEl The most users online at one time was 348 on 09-01-2011 at 12:38 AM
Mark All Forums Read | Forum Team | Forum Statistics

  Forum Contains New Posts
  Forum Contains No New Posts
  Forum is Locked